==> uaddress-1.0.8.tar.gz: uaddress-1.0.8/uaddress/types.py <==
TYPES = {

    # REGION
    "обл", "обл.", "область",
    # CITY
    "м", "м.", "місто", "г", "г.", "город",
    # DISTRICT
    "р-н", "р-н.", "рн", "рн.", "р-он", "район",
    # MICRODISTRICT
    "мікр", "мікр.", "мн", "мр", "мкрн", "мкр", "мікрорайон", "микр", "микр.", "микрорайон", "м-н", "м-р",
    # VILLAGE
    "пос", "пос.", "смт", "смт.", "с.м.т", "пгт", "п г т", "пгт.", "село", "селище", "поселок", "с-ще",
    # STREET    
    "вул", "вул.", "вулиця", "ул", "ул.", "улица", "влу.", "в.", "вулю", "улиця",
    "пров", "пров.", "провулок", "пер", "пер.", "переулок", "прос", "провул", "прв.", "перевуло", "про",
    "бул", "бул.", "б-р", "бр", "бр.", "бур", "бур.", "бульвар", "бульв.", "бул-р.",
    "просп", "просп.", "прт", "прт.", "прокт", "прокт.", "пр", "пр.", "п-т", "п-т.", "п-рт.", "проспект", "п-т", "пр-кт", "пр-к", "прпосп"
    "ж\м", "ж/м", "масив", "массив", "житловий масив", "жилой массив", "ж.м.",
    "ш.", "шосе", "шоссе",
    "алея", "аллея",
    "майд", "майд.", "майдан",
    "розвилка", "развилка",
    "узвіз", "спуск",
    "проїзд", "проезд", "пр-д",
    "дорога",
    "наб", "наб.", "набер.", "набережна", "набережная",
    "парк",
    "сквер",
    "тупик",
    "прохід", "проход",
    "ст", "ст.", "станція", "станция",
    "остр", "остр.", "острів", "остров",
    "шлях", "путь",
    "гай", "роща", 
    "пл", "пл.", "площа", "площадь",
    "в'їзд", "въезд",
    "лінія", "линия",
    "траса", "трасса",
    "урочище",
    "шахта",
    "хутір", "хутор",
    "роз'їзд", "разъезд",
    "квартал", "кв-л",
    "присілок",
    "плесо",
    "завулок", "проулок", "зав.",
    # HOUSING
    "корп.", "корп", "корпус",
    # HOSTEL
    "гурт", "гурт.", "гуртожиток", "общ", "общ.", "общежитие",
    # HOUSE
    "буд.", "будинок", "дом", "д.", "б.", "зд", "зд.",
    # APARTMENT
    "кв.", "квартира",
    # ROOM
    "прим.",
    # SECTION
    "секція",
    # ENTRANCE
    "підʼїзд", "подъезд",
    # FLOOR
    "поверх", "этаж"
    
}

==> uaddress-1.0.9.tar.gz: uaddress-1.0.9/uaddress/types.py <==
TYPES = {

    # REGION
    "обл", "обл.", "область",
    # CITY
    "м", "м.", "місто", "г", "г.", "город",
    # DISTRICT
    "р-н", "р-н.", "рн", "рн.", "р-он", "район",
    # MICRODISTRICT
    "мікр", "мікр.", "мн", "мр", "мкрн", "мкр", "мікрорайон", "микр", "микр.", "микрорайон", "м-н", "м-р",
    # VILLAGE
    "пос", "пос.", "смт", "смт.", "с.м.т", "пгт", "п г т", "пгт.", "село", "селище", "поселок", "с-ще",
    # STREET    
    "вул", "вул.", "вулиця", "ул", "ул.", "улица", "влу.", "в.", "вулю", "улиця",
    "пров", "пров.", "провулок", "пер", "пер.", "переулок", "прос", "провул", "провул.", "прв.", "перевуло", "про",
    "бул", "бул.", "б-р", "бр", "бр.", "бур", "бур.", "бульвар", "бульв.", "бул-р.", "буль.", "б_р",
    "просп", "просп.", "прт", "прт.", "прокт", "прокт.", "пр", "пр.", "п-т", "п-т.", "п-рт.", "проспект", "п-т", "пр-кт", "пр-к", "прпосп", "пр_т", "прʼт",
    "ж\м", "ж/м", "масив", "массив", "житловий масив", "жилой массив", "ж.м.",
    "ш.", "шосе", "шоссе",
    "алея", "аллея",
    "майд", "майд.", "майдан",
    "розвилка", "развилка",
    "узвіз", "спуск", "узв",
    "проїзд", "проезд", "пр-д",
    "дорога",
    "наб", "наб.", "набер.", "набережна", "набережная",
    "парк",
    "сквер",
    "тупик",
    "прохід", "проход",
    "ст", "ст.", "станція", "станция",
    "остр", "остр.", "острів", "остров",
    "шлях", "путь",
    "гай", "роща", 
    "пл", "пл.", "площа", "площадь",
    "в'їзд", "въезд",
    "лінія", "линия",
    "траса", "трасса",
    "урочище",
    "шахта",
    "хутір", "хутор",
    "роз'їзд", "разъезд",
    "квартал", "кв-л",
    "присілок",
    "плесо",
    "завулок", "проулок", "зав.",
    # HOUSING
    "корп.", "корп", "корпус",
    # HOSTEL
    "гурт", "гурт.", "гуртожиток", "общ", "общ.", "общежитие",
    # HOUSE
    "буд.", "будинок", "дом", "д.", "б.", "зд", "зд.",
    # APARTMENT
    "кв.", "квартира",
    # ROOM
    "прим.",
    # SECTION
    "секція", "секц",
    # ENTRANCE
    "підʼїзд", "подъезд",
    # FLOOR
    "поверх", "этаж"
    
}
